#
# spec file for package ghc-foldl
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name foldl
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.12
Release:        bp155.3.14
Summary:        Composable, streaming, and efficient left folds
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-profunctors-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroupoids-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif

%description
This library provides strict left folds that stream in constant memory, and you
can combine folds using 'Applicative' style to derive new folds.
Derived folds still traverse the container just once and are often as efficient
as hand-written folds.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Fri Dec 24 2021 Peter Simons <psimons@suse.com>
- Update foldl to version 1.4.12 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jul 10 2021 psimons@suse.com
- Update foldl to version 1.4.12.
  1.4.12
  * `Data.Functor.Extend.Extended` instances for `Fold` / `FoldM`
  * Remove dependency on `mwc-random`
* Thu Feb 25 2021 psimons@suse.com
- Update foldl to version 1.4.11.
  1.4.11
  * Fix doctest failure when built against newer versions of the `hashable`
    package
* Mon Jan  4 2021 psimons@suse.com
- Update foldl to version 1.4.10 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov  3 2020 psimons@suse.com
- Update foldl to version 1.4.10.
  1.4.10
  * Fix space leaks in `scan` / `scanM`
* Tue Oct  6 2020 psimons@suse.com
- Update foldl to version 1.4.9 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Sep 28 2020 psimons@suse.com
- Update foldl to version 1.4.9.
  1.4.9
  * Implement `vector` utility more efficiently
* Mon Aug 31 2020 psimons@suse.com
- Update foldl to version 1.4.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug  4 2020 psimons@suse.com
- Update foldl to version 1.4.8.
  1.4.8
  * Only depend on `semigroups` for older GHC versions
* Sun Jun 21 2020 psimons@suse.com
- Update foldl to version 1.4.7.
  1.4.7
  * Add `foldByKey{,Hash}Map` functions
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Sat Jan 11 2020 psimons@suse.com
- Update foldl to version 1.4.6.
  1.4.6
  * Add `nest`/`predropWhile`/`drop`/`dropM`
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Fri May 17 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Thu Oct  4 2018 psimons@suse.com
- Update foldl to version 1.4.5.
  1.4.5
  * Increase upper bound on `containers`
  * Add `either`/`eitherM`
  1.4.4
  * Increase lower bound on `base`
  * Change `mean` to be more numerically stable
* Fri Aug 17 2018 psimons@suse.com
- Update foldl to version 1.4.3.
  1.4.3
  * Add `Control.Scanl.scanr`
  * Increase upper bound on `mwc-random`
* Fri Jul 20 2018 psimons@suse.com
- Add foldl at version 1.4.2.
